Added support for using static libraries in sdk snapshot
Parameterized the cc.librarySdkMemberType to allow it to support
both static and shared libraries. Created two instances, one for shared
and one for static libraries. A follow up change will add support for
libraries that can be both.
Added *librarySdkMemberType to nativeMemberInfo as information from
there is needed when generating the snapshot.
Made organizeVariants() func a method of *librarySdkMemberType so that
it can initialize the new field. Moved it to be with all the other
methods of that type.
Added host and device tests for the new module type.
Bug: 142918168
Test: m nothing
Change-Id: I00b1e8424b9d81f7d15edc4883971d10668ec2cc
diff --git a/sdk/sdk.go b/sdk/sdk.go
index 8c5c8d8..cd9aafa 100644
--- a/sdk/sdk.go
+++ b/sdk/sdk.go
@@ -63,9 +63,12 @@
type sdkProperties struct {
// For module types from the cc package
// The list of native libraries in this SDK
Native_shared_libs []string
+ // The list of static native libraries in this SDK
+ Native_static_libs []string
+
// For module types from the java package
// The list of java header libraries in this SDK
@@ -114,7 +117,12 @@
{
name: "native_shared_libs",
getter: func(properties *sdkProperties) []string { return properties.Native_shared_libs },
- memberType: cc.LibrarySdkMemberType,
+ memberType: cc.SharedLibrarySdkMemberType,
+ },
+ {
+ name: "native_static_libs",
+ getter: func(properties *sdkProperties) []string { return properties.Native_static_libs },
+ memberType: cc.StaticLibrarySdkMemberType,
},
// Members from java package.
{
@@ -63,9 +63,12 @@
type sdkProperties struct {
// For module types from the cc package
- // The list of native libraries in this SDK
+ // The list of shared native libraries in this SDK
Native_shared_libs []string